// Author: Pete Kirkham
// tiny quad store benchmark.
//
// tests the file_reader works copying a file.

#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <stdlib.h>
#include <iostream>

#define KiB (1024)
#define MiB (1024*1024)

#include "io/file_reader.h"

int main (int narg, char** argvp)
{
    if (narg < 2)
    {
        std::cerr << "The input file name and the number of MiB to read are required." << std::endl;
        return 1;
    }

    size_t max_read(narg > 2 ? atoi(argvp[2]) * MiB : std::numeric_limits<size_t>::max());

    // open the file
    int file(open(argvp[1], O_RDONLY));

    if (!file)
    {
        std::cerr << "failed to open " << argvp[1] << std::endl;
        return 2;
    }

    file_reader  reader(file);

    // read in data
    do
    {
        std::cout << reader.read(1024);
    }
    while (reader.ok() && reader.total_read() < max_read);

    if (reader.failed())
    {
        std::cerr << "Reader failed at " << reader.total_read() << " with '" << reader.last() << "'" << std::endl;
    }

    close(file);

    return 0;
}
